@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2018, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -40,14 +40,14 @@ namespace mozc {
 namespace {
 
 // base/embedded_file.h is embedded as kEmbeddedFileTestData.
-#include "base/embedded_file_test_data.h"
+#include "base/embedded_file_test_data.inc"
 
 #ifndef OS_NACL
 // NaCl test doesn't support real file system, so currently disabled.
 TEST(EmbeddedFileTest, Basic) {
   const string expected = InputFileStream(
       testing::GetSourceFileOrDie({"base", "embedded_file.h"}).c_str(),
-      ios_base::in | ios_base::binary).Read();
+      std::ios_base::in | std::ios_base::binary).Read();
   EXPECT_EQ(expected, LoadEmbeddedFile(kEmbeddedFileTestData));
 }
 #endif  // OS_NACL
