@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2018, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -34,10 +34,10 @@
 #endif  // OS_WIN
 
 #include <fstream>
+#include <string>
 
 #include "base/file_stream.h"
 #include "base/logging.h"
-#include "base/number_util.h"
 #include "base/util.h"
 #include "testing/base/public/gunit.h"
 
@@ -134,7 +134,7 @@ TEST_F(FileUtilTest, Unlink) {
     FILE_ATTRIBUTE_TEMPORARY,
   };
 
-  wstring wfilepath;
+  std::wstring wfilepath;
   Util::UTF8ToWide(filepath, &wfilepath);
   for (size_t i = 0; i < arraysize(kTestAttributeList); ++i) {
     SCOPED_TRACE(Util::StringPrintf("AttributeTest %zd", i));
@@ -157,7 +157,7 @@ TEST_F(FileUtilTest, HideFile) {
 
   EXPECT_FALSE(FileUtil::HideFile(filename));
 
-  wstring wfilename;
+  std::wstring wfilename;
   Util::UTF8ToWide(filename.c_str(), &wfilename);
 
   CreateTestFile(filename, "test data");
@@ -262,12 +262,12 @@ TEST_F(FileUtilTest, CopyFile) {
 
   for (size_t i = 0; i < arraysize(kTestDataList); ++i) {
     const string test_label =
-        "overwrite test with attributes " + NumberUtil::SimpleItoa(i);
+        "overwrite test with attributes " + std::to_string(i);
     SCOPED_TRACE(test_label);
     CreateTestFile(from, test_label);
 
     const TestData &kData = kTestDataList[i];
-    wstring wfrom, wto;
+    std::wstring wfrom, wto;
     Util::UTF8ToWide(from.c_str(), &wfrom);
     Util::UTF8ToWide(to.c_str(), &wto);
     EXPECT_NE(FALSE,
@@ -351,12 +351,12 @@ TEST_F(FileUtilTest, AtomicRename) {
 
   for (size_t i = 0; i < arraysize(kTestDataList); ++i) {
     const string test_label =
-        "overwrite file with attributes " + NumberUtil::SimpleItoa(i);
+        "overwrite file with attributes " + std::to_string(i);
     SCOPED_TRACE(test_label);
     CreateTestFile(from, test_label);
 
     const TestData &kData = kTestDataList[i];
-    wstring wfrom, wto;
+    std::wstring wfrom, wto;
     Util::UTF8ToWide(from.c_str(), &wfrom);
     Util::UTF8ToWide(to.c_str(), &wto);
     EXPECT_NE(FALSE,
