@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2018, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -865,7 +865,7 @@ bool Client::LaunchTool(const string &mode, const string &extra_arg) {
   if (mode == "administration_dialog") {
 #ifdef OS_WIN
     const string &path = mozc::SystemUtil::GetToolPath();
-    wstring wpath;
+    std::wstring wpath;
     Util::UTF8ToWide(path, &wpath);
     wpath = L"\"" + wpath + L"\"";
     // Run administration dialog with UAC.
