@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2018, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -44,8 +44,8 @@
 namespace mozc {
 namespace composer {
 
-using mozc::config::Config;
-using mozc::config::ConfigHandler;
+using ::mozc::config::Config;
+using ::mozc::config::ConfigHandler;
 
 // Embedded cost for testing purpose.
 class CostTableForTest {
@@ -358,63 +358,36 @@ TEST_F(TypingCorrectorTest, TypingCorrection) {
     const char *correction;
     const char *exact_composition;
   } kTestCases[] = {
-    // "phayou" -> "おはよう", "ｐはよう"
-    { "phayou",
-      "\xE3\x81\x8A\xE3\x81\xAF\xE3\x82\x88\xE3\x81\x86",
-      "\xEF\xBD\x90\xE3\x81\xAF\xE3\x82\x88\xE3\x81\x86"},
-    // "orukaresama" -> "おつかれさま", "おるかれさま"
-    { "orukaresama",
-      "\xE3\x81\x8A\xE3\x81\xA4\xE3\x81\x8B"
-          "\xE3\x82\x8C\xE3\x81\x95\xE3\x81\xBE",
-      "\xE3\x81\x8A\xE3\x82\x8B\xE3\x81\x8B"
-          "\xE3\x82\x8C\xE3\x81\x95\xE3\x81\xBE"},
-    // "gu-huru" -> "ぐーぐる", "ぐーふる"
-    { "gu-huru",
-      "\xE3\x81\x90\xE3\x83\xBC\xE3\x81\x90\xE3\x82\x8B",
-      "\xE3\x81\x90\xE3\x83\xBC\xE3\x81\xB5\xE3\x82\x8B"},
-    // "bihongo" -> "にほんご", "びほんご"
-    { "bihongo",
-      "\xE3\x81\xAB\xE3\x81\xBB\xE3\x82\x93\xE3\x81\x94",
-      "\xE3\x81\xB3\xE3\x81\xBB\xE3\x82\x93\xE3\x81\x94"},
-    // "yajiniku" -> "やきにく", "やじにく"
-    { "yajiniku",
-      "\xE3\x82\x84\xE3\x81\x8D\xE3\x81\xAB\xE3\x81\x8F",
-      "\xE3\x82\x84\xE3\x81\x98\xE3\x81\xAB\xE3\x81\x8F"},
-    // "so-natsu" -> "どーなつ", "そーなつ"
-    { "so-natsu",
-      "\xE3\x81\xA9\xE3\x83\xBC\xE3\x81\xAA\xE3\x81\xA4",
-      "\xE3\x81\x9D\xE3\x83\xBC\xE3\x81\xAA\xE3\x81\xA4"},
-    // "ohayou" -> NULL, "おはよう"
-    // "おはよう" can be generated from raw key so
-    // it shouldn't be in correction candidates.
-    { "ohayou",
-      NULL,
-      "\xE3\x81\x8A\xE3\x81\xAF\xE3\x82\x88\xE3\x81\x86"},
-    // "syamoji" -> NULL, "しゃもじ"
-    // A query which can be composed from raw input
-    // shouldn't be in correction candidates.
-    // This is more complex pattern than "おはよう" test case.
-    // "おはよう" case can be processed correctly by comparing
-    // raw input and corrected query.
-    // But this case "syamoji" (raw input) and "shamoji" (corrected input)
-    // are different but their query is identical ("しゃもじ").
-    // Thus we have to also check not only raw/corrected input but also
-    // raw/corrected queries.
-    { "syamozi",
-      NULL,
-      "\xE3\x81\x97\xE3\x82\x83\xE3\x82\x82\xE3\x81\x98"},
-    // "kaish" -> NULL, "かいしゃ"
-    // Pending input is expanded into possible queries for
-    // kana-modifier-insensitive-conversion (a.k.a かつこう変換).
-    // In this case "kaish" is expanded into "かいしゃ", "かいしゅ"
-    // and so on.
-    // Typing corrected input "kaisy" is also expanded into
-    // "かいしゃ", "かいしゅ" and so on but they are duplicate
-    // of expanded queries from "kaish".
-    // Thus they shouldn't be in corrected candidates.
-    { "kaish",
-      NULL,
-      "\xE3\x81\x8B\xE3\x81\x84\xE3\x81\x97\xE3\x82\x83"},
+      {"phayou", "おはよう", "ｐはよう"},
+      {"orukaresama", "おつかれさま", "おるかれさま"},
+      {"gu-huru", "ぐーぐる", "ぐーふる"},
+      {"bihongo", "にほんご", "びほんご"},
+      {"yajiniku", "やきにく", "やじにく"},
+      {"so-natsu", "どーなつ", "そーなつ"},
+      // "おはよう" can be generated from raw key so
+      // it shouldn't be in correction candidates.
+      {"ohayou", nullptr, "おはよう"},
+      // "syamoji" -> nullptr, "しゃもじ"
+      // A query which can be composed from raw input
+      // shouldn't be in correction candidates.
+      // This is more complex pattern than "おはよう" test case.
+      // "おはよう" case can be processed correctly by comparing
+      // raw input and corrected query.
+      // But this case "syamoji" (raw input) and "shamoji" (corrected input)
+      // are different but their query is identical ("しゃもじ").
+      // Thus we have to also check not only raw/corrected input but also
+      // raw/corrected queries.
+      {"syamozi", nullptr, "しゃもじ"},
+      // "kaish" -> nullptr, "かいしゃ"
+      // Pending input is expanded into possible queries for
+      // kana-modifier-insensitive-conversion (a.k.a かつこう変換).
+      // In this case "kaish" is expanded into "かいしゃ", "かいしゅ"
+      // and so on.
+      // Typing corrected input "kaisy" is also expanded into
+      // "かいしゃ", "かいしゅ" and so on but they are duplicate
+      // of expanded queries from "kaish".
+      // Thus they shouldn't be in corrected candidates.
+      {"kaish", nullptr, "かいしゃ"},
   };
 
   for (size_t i = 0; i < arraysize(kTestCases); ++i) {
@@ -468,7 +441,7 @@ TEST_F(TypingCorrectorTest, CopyFrom) {
   corrector.SetConfig(&config_);
   InsertOneByOne("phayou", &corrector);
 
-  TypingCorrector corrector2(NULL, 1000, 1000);
+  TypingCorrector corrector2(nullptr, 1000, 1000);
   corrector2.CopyFrom(corrector);
 
   ExpectTypingCorrectorEqual(corrector, corrector2);
