@@ -1,4 +1,4 @@
-// Copyright 2010-2016, Google Inc.
+// Copyright 2010-2018, Google Inc.
 // All rights reserved.
 //
 // Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,7 @@
 
 #include <algorithm>
 #include <memory>
+#include <random>
 #include <string>
 #include <vector>
 
@@ -73,7 +74,9 @@ TEST(ConnectorTest, CompareWithRawData) {
 
   for (int trial = 0; trial < 3; ++trial) {
     // Lookup in random order for a few times.
-    std::random_shuffle(data.begin(), data.end());
+    std::random_device rd;
+    std::mt19937 urbg(rd());
+    std::shuffle(data.begin(), data.end(), urbg);
     for (size_t i = 0; i < data.size(); ++i) {
       int actual = connector->GetTransitionCost(data[i].rid, data[i].lid);
       EXPECT_EQ(data[i].cost, actual);
